summaryrefslogtreecommitdiff
path: root/src/theory/quantifiers/sygus/cegis.h
diff options
context:
space:
mode:
authorAndrew Reynolds <andrew.j.reynolds@gmail.com>2018-09-18 10:26:36 -0500
committerGitHub <noreply@github.com>2018-09-18 10:26:36 -0500
commitfa557c39a89a2c8de198ea0400e6936c1790ad4e (patch)
treef1b2ff7512b3aec3a06d5a879dc930e559ae172e /src/theory/quantifiers/sygus/cegis.h
parentd718da758b27c2824d2aff44faf71971133217ab (diff)
Move and rename sygus solver classes (#2488)
Diffstat (limited to 'src/theory/quantifiers/sygus/cegis.h')
-rw-r--r--src/theory/quantifiers/sygus/cegis.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/theory/quantifiers/sygus/cegis.h b/src/theory/quantifiers/sygus/cegis.h
index ce4186eb2..c7392b378 100644
--- a/src/theory/quantifiers/sygus/cegis.h
+++ b/src/theory/quantifiers/sygus/cegis.h
@@ -41,7 +41,7 @@ namespace quantifiers {
class Cegis : public SygusModule
{
public:
- Cegis(QuantifiersEngine* qe, CegConjecture* p);
+ Cegis(QuantifiersEngine* qe, SynthConjecture* p);
~Cegis() override {}
/** initialize */
virtual bool initialize(Node n,
@@ -69,11 +69,11 @@ class Cegis : public SygusModule
protected:
/** the evaluation unfold utility of d_tds */
SygusEvalUnfold* d_eval_unfold;
/** If CegConjecture::d_base_inst is exists y. P( d, y ), then this is y. */
std::vector<Node> d_base_vars;
/**
* If CegConjecture::d_base_inst is exists y. P( d, y ), then this is the
* formula P( CegConjecture::d_candidates, y ).
*/
Node d_base_body;
//----------------------------------cegis-implementation-specific
@@ -69,11 +69,11 @@ class Cegis : public SygusModule
/** the evaluation unfold utility of d_tds */
SygusEvalUnfold* d_eval_unfold;
- /** If CegConjecture::d_base_inst is exists y. P( d, y ), then this is y. */
+ /** If SynthConjecture::d_base_inst is exists y. P( d, y ), then this is y. */
std::vector<Node> d_base_vars;
/**
@@ -69,11 +69,11 @@ class Cegis : public SygusModule
std::vector<Node> d_base_vars;
/**
- * If CegConjecture::d_base_inst is exists y. P( d, y ), then this is the
- * formula P( CegConjecture::d_candidates, y ).
+ * If SynthConjecture::d_base_inst is exists y. P( d, y ), then this is the
+ * formula P( SynthConjecture::d_candidates, y ).
*/
Node d_base_body;
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback